websocket_client: WebSocket client for Python with low level API options
========================================================================

Description
-----------

WebSocket client for Python with low level API options

License
-------

Apache-2.0

Upstream Contact
----------------

https://pypi.org/project/websocket-client/

